@@ -2,7 +2,7 @@ package WebService::ILS;
 
 use Modern::Perl;
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 =encoding utf-8
 
@@ -565,6 +565,10 @@ Example:
 
 =head3 Returns true if the error is access token related
 
+=head2 is_not_authenticated_error ($exception_string)
+
+=head3 Returns true if the error is "Not authenticated"
+
 =cut
 
 sub error_message {
@@ -580,6 +584,12 @@ sub is_access_token_error {
     return $self->error_message($die_string) eq ERROR_ACCESS_TOKEN;
 }
 
+sub is_not_authenticated_error {
+    my $self = shift;
+    my $die_string = shift or croak "No error message";
+    return $self->error_message($die_string) eq ERROR_NOT_AUTHENTICATED;
+}
+
 # Client access authorization
 #
 sub _request_with_auth {
