@@ -38,13 +38,19 @@ use constant OAUTH_BASE_URL => "https://oauth.overdrive.com/";
 use constant TOKEN_URL => OAUTH_BASE_URL . 'token';
 use constant AUTH_URL => OAUTH_BASE_URL . 'auth';
 
+sub format_is_lockable {
+    my $self = shift;
+    my $format = shift or croak "No format";
+    return !scalar( grep { $_ eq $format } @{ NON_LOCKABLE_FORMATS() } );
+}
+
 =head1 CONSTRUCTOR
 
 =head2 new (%params_hash or $params_hashref)
 
 =head3 Additional constructor params:
 
-=over 12
+=over 16
 
 =item C<auth_token> => auth token as previously obtained
 
@@ -152,12 +158,14 @@ An example:
 
 =head3 Input params:
 
-=over 12
+=over 18
 
 =item C<redirect_uri> => return url which will handle redirect back after auth
 
-=item C<state_token>  => a token that is returned back unchanged,
-                         for additional security; not required
+=item C<state_token>  => a token that is returned back unchanged;
+
+for additional security; not required
+
 =back
 
 =cut
@@ -376,10 +384,14 @@ sub checkouts {
 
     my $res = $self->_result_xlate($checkouts, \%CHECKOUTS_XLATE);
     $res->{items} = [
-        map { {
-            %{ $self->_checkout_item_xlate($_) },
-            %{ $self->_item_metadata($_) },
-        } } @$items
+        map {
+            my $metadata = $self->_item_metadata($_);
+            if (my $formats = $metadata->{formats}) {
+                $metadata->{formats} = [ grep { $self->format_is_lockable($_) } @$formats ];
+            };
+            my %item = ( %{ $self->_checkout_item_xlate($_) }, %$metadata );
+            \%item;
+        } @$items
     ];
     return $res;
 }
@@ -435,7 +447,7 @@ sub checkout {
 
 =head2 checkout_formats ($item_id)
 
-=head3 Returns an array of available formats
+=head3 Returns an array of available checked out formats
 
 =cut
 
@@ -664,7 +676,7 @@ sub native_lock_format {
     my $item_id = shift or croak "No item id";
     my $format = shift or croak "No format";
 
-    croak "Format $format not lockable" if grep { $_ eq $format } @{ NON_LOCKABLE_FORMATS() };
+    croak "Format $format not lockable" unless $self->format_is_lockable($format);
 
     my $url = $self->circulation_action_url("/checkouts/$item_id/formats");
     return $self->with_json_request(
